"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getHighlighter = getHighlighter;
exports.getLoadedLanguages = getLoadedLanguages;
exports.getSafeLanguage = getSafeLanguage;
exports.getThemeContext = getThemeContext;
exports.isValidLanguage = isValidLanguage;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _vscodeTextmate = require("@shikijs/vscode-textmate");
var _css = _interopRequireDefault(require("shiki/dist/langs/css.mjs"));
var _html = _interopRequireDefault(require("shiki/dist/langs/html.mjs"));
var _javascript = _interopRequireDefault(require("shiki/dist/langs/javascript.mjs"));
var _json = _interopRequireDefault(require("shiki/dist/langs/json.mjs"));
var _markdown = _interopRequireDefault(require("shiki/dist/langs/markdown.mjs"));
var _php = _interopRequireDefault(require("shiki/dist/langs/php.mjs"));
var _tsx = _interopRequireDefault(require("shiki/dist/langs/tsx.mjs"));
var _typescript = _interopRequireDefault(require("shiki/dist/langs/typescript.mjs"));
var _githubDark = _interopRequireDefault(require("shiki/dist/themes/github-dark.mjs"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable no-console */

// Import languages

const DEBUG = true;
function log(message, ...args) {
  if (DEBUG) {
    console.log(`[ShikiContext] ${message}`, ...args);
  }
}
function processLanguage(lang) {
  if (!lang) {
    throw new Error('Invalid language definition');
  }
  return {
    name: lang.name || lang.id,
    scopeName: lang.scopeName,
    aliases: lang.aliases || [],
    embeddedLangs: lang.embeddedLanguages,
    grammar: {
      repository: lang.repository,
      patterns: lang.patterns
    }
  };
}

// Define raw languages
const rawLanguages = {
  typescript: {
    ..._typescript.default,
    name: 'typescript',
    aliases: ['ts']
  },
  javascript: {
    ..._javascript.default,
    name: 'javascript',
    aliases: ['js']
  },
  tsx: {
    ..._tsx.default,
    name: 'tsx',
    aliases: ['jsx']
  },
  css: {
    ..._css.default,
    name: 'css'
  },
  html: {
    ..._html.default,
    name: 'html'
  },
  json: {
    ..._json.default,
    name: 'json'
  },
  markdown: {
    ..._markdown.default,
    name: 'markdown',
    aliases: ['md']
  },
  php: {
    ..._php.default,
    name: 'php'
  },
  plaintext: {
    id: 'plaintext',
    scopeName: 'source.plaintext',
    grammar: {
      patterns: [{
        match: '.*',
        name: 'text.plain'
      }]
    }
  }
};

// Process languages into proper registrations
const languageRegistrations = new Map();
for (const [key, lang] of Object.entries(rawLanguages)) {
  try {
    const registration = processLanguage(lang);
    languageRegistrations.set(key, registration);
    // Also register by scopeName for lookups
    languageRegistrations.set(registration.scopeName, registration);
    // Register aliases
    registration.aliases?.forEach(alias => {
      languageRegistrations.set(alias, registration);
    });
  } catch (error) {
    log(`Failed to process language ${key}:`, error);
  }
}
function normalizeTheme(rawTheme) {
  const theme = {
    ...rawTheme
  };
  theme.type ||= 'dark';
  theme.settings ||= [];
  theme.colorReplacements ||= {};
  if (theme.tokenColors && !theme.settings) {
    theme.settings = theme.tokenColors;
    delete theme.tokenColors;
  }
  theme.settings ||= [];
  theme.bg ||= theme.type === 'dark' ? '#1e1e1e' : '#ffffff';
  theme.fg ||= theme.type === 'dark' ? '#bbbbbb' : '#333333';
  if (!theme.settings[0] || !theme.settings[0].settings || theme.settings[0].scope) {
    theme.settings.unshift({
      settings: {
        foreground: theme.fg,
        background: theme.bg
      }
    });
  }
  return theme;
}
const highlighterInstance = null;
const themeCache = new Map();
function getThemeContext(theme) {
  const themeId = typeof theme === 'string' ? theme : theme.name || 'default';
  if (!themeCache.has(themeId)) {
    const normalizedTheme = normalizeTheme(theme);
    const textmateTheme = _vscodeTextmate.Theme.createFromRawTheme(normalizedTheme);
    themeCache.set(themeId, {
      theme: normalizedTheme,
      textmateTheme
    });
  }
  return themeCache.get(themeId);
}
async function getHighlighter() {
  if (highlighterInstance) {
    log('Returning cached highlighter instance');
    return highlighterInstance;
  }
  try {
    log('Creating new highlighter instance...');

    // Process default theme
    const defaultTheme = getThemeContext(_githubDark.default);

    // Initialize regex engine
    const engine = (0, _engineJavascript.createJavaScriptRegexEngine)();

    // Get language registrations
    const validLanguages = Array.from(languageRegistrations.values());
    log('Loading languages:', validLanguages.map(l => l.name));

    // Modified version of the language handling code
    const highlighterInstance = await (0, _core.createHighlighterCore)({
      themes: [defaultTheme.theme],
      langs: validLanguages,
      engine
    });

    // Add this check
    if (!highlighterInstance) {
      throw new Error('Failed to create highlighter instance');
    }

    // Get loaded languages using the correct method
    const loadedLangs = highlighterInstance.getLoadedLanguages?.() || [];
    log('Successfully loaded languages:', loadedLangs);
    return highlighterInstance;
  } catch (error) {
    log('Error creating highlighter:', error);
    throw error;
  }
}
function isValidLanguage(lang) {
  return languageRegistrations.has(lang.toLowerCase());
}
function getSafeLanguage(lang) {
  const normalized = lang.toLowerCase();
  const registration = languageRegistrations.get(normalized);
  if (registration) {
    return registration.name;
  }
  log(`Warning: Unsupported language '${lang}', falling back to plaintext`);
  return 'plaintext';
}

// For debugging
function getLoadedLanguages() {
  return Array.from(languageRegistrations.keys());
}
//# sourceMappingURL=SyntaxContext.js.map